@@ -54,7 +54,7 @@ class JQueryTools extends CGExtensions
 
   function GetName() { return 'JQueryTools'; }
   function GetFriendlyName() { return $this->Lang('friendlyname'); }
-  function GetVersion() { return '1.2.3'; }
+  function GetVersion() { return '1.2.5'; }
   function GetHelp() { return file_get_contents(dirname(__FILE__).'/help.inc'); }
   function GetAuthor() { return 'calguy1000'; }
   function GetAuthorEmail() { return 'calguy1000@cmsmadesimple.org'; }
@@ -65,10 +65,12 @@ class JQueryTools extends CGExtensions
   function GetAdminDescription() { return $this->Lang('moddescription'); }
   function VisibleToAdminUser() { return false; }
   function GetDependencies() { return array('CGExtensions'=>'1.31'); }
-  function MinimumCMSVersion() { return "1.11.1"; }
+  function MinimumCMSVersion() { return "1.11.3"; }
   function InstallPostMessage() { return $this->Lang('postinstall'); }
   function UninstallPostMessage() { return $this->Lang('postuninstall'); }
   function UninstallPreMessage() { return $this->Lang('preuninstall'); }
+  function AllowAutoInstall() { return FALSE; }
+  function AllowAutoUpgrade() { return FALSE; }
 
   function InitializeFrontend()
   {
@@ -79,6 +81,7 @@ class JQueryTools extends CGExtensions
     $this->SetParameterType('no_cdn',CLEAN_INT);
     $this->SetParameterType('no_js',CLEAN_INT);
     $this->SetParameterType('no_jquery',CLEAN_INT);
+    $this->SetParameterType('no_ready',CLEAN_INT);
     $this->SetParameterType('lib',CLEAN_STRING);
   }
 
@@ -92,6 +95,7 @@ class JQueryTools extends CGExtensions
     $this->CreateParameter('no_cdn',null,$this->Lang('param_no_cdn'));
     $this->CreateParameter('no_js',null,$this->Lang('param_no_js'));
     $this->CreateParameter('no_jquery',null,$this->Lang('param_no_jquery'));
+    $this->CreateParameter('no_ready',null,$this->Lang('param_no_ready'));
   }
 
 } // class
